@@ -1,10 +1,10 @@
-/* $Id: avl_DoWithAll.cpp.h 83575 2013-02-04 14:27:54Z fmehnert $ */
+/* $Id: avl_DoWithAll.cpp.h 118810 2017-10-28 13:12:06Z bird $ */
 /** @file
  * kAVLDoWithAll - Do with all nodes routine for AVL trees.
  */
 
 /*
- * Copyright (C) 1999-2011 knut st. osmundsen (bird-src-spam@anduin.net)
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -47,7 +47,7 @@ KAVL_DECL(int) KAVL_FN(DoWithAll)(PPKAVLNODECORE ppTree, int fFromLeft, PKAVLCAL
     int             rc;
 
     if (*ppTree == KAVL_NULL)
-        return 0;
+        return VINF_SUCCESS;
 
     AVLStack.cEntries = 1;
     AVLStack.achFlags[0] = 0;
@@ -72,14 +72,14 @@ KAVL_DECL(int) KAVL_FN(DoWithAll)(PPKAVLNODECORE ppTree, int fFromLeft, PKAVLCAL
 
             /* center */
             rc = pfnCallBack(pNode, pvParam);
-            if (rc)
+            if (rc != VINF_SUCCESS)
                 return rc;
 #ifdef KAVL_EQUAL_ALLOWED
             if (pNode->pList != KAVL_NULL)
                 for (pEqual = KAVL_GET_POINTER(&pNode->pList); pEqual; pEqual = KAVL_GET_POINTER_NULL(&pEqual->pList))
                 {
                     rc = pfnCallBack(pEqual, pvParam);
-                    if (rc)
+                    if (rc != VINF_SUCCESS)
                         return rc;
                 }
 #endif
@@ -112,14 +112,14 @@ KAVL_DECL(int) KAVL_FN(DoWithAll)(PPKAVLNODECORE ppTree, int fFromLeft, PKAVLCAL
 
             /* center */
             rc = pfnCallBack(pNode, pvParam);
-            if (rc)
+            if (rc != VINF_SUCCESS)
                 return rc;
 #ifdef KAVL_EQUAL_ALLOWED
             if (pNode->pList != KAVL_NULL)
                 for (pEqual = KAVL_GET_POINTER(&pNode->pList); pEqual; pEqual = KAVL_GET_POINTER_NULL(&pEqual->pList))
                 {
                     rc = pfnCallBack(pEqual, pvParam);
-                    if (rc)
+                    if (rc != VINF_SUCCESS)
                         return rc;
                 }
 #endif
@@ -134,7 +134,7 @@ KAVL_DECL(int) KAVL_FN(DoWithAll)(PPKAVLNODECORE ppTree, int fFromLeft, PKAVLCAL
         } /* while */
     }
 
-    return 0;
+    return VINF_SUCCESS;
 }
 
 
